#!/usr/bin/python3
#
# Licensed under the terms of the GNU GPL License version 2

from __future__ import print_function
from openidc_client import OpenIDCClient
from openidc_client.requestsauth import OpenIDCClientAuther
import requests
import sys

try:
    lpos = sys.argv.index("-l")
    log = sys.argv[lpos+1]
    if len(sys.argv) > 3:
        print(
            "Warning: config file contains your username and password! This "
            "is no longer needed. Edit .config and remove them"
        )
except (ValueError, IndexError):
    log = sys.argv[1:]
    if len(log) != 1 or log == ["-l"]:
        print('fedora_submit.py <logfile> or fedora_submit.py -l <logfile>')
        sys.exit(2)
    log = log[0]
print(log)

client = OpenIDCClient(
    app_identifier="kerneltest",
    id_provider=f"https://id.fedoraproject.org/openidc/",
    id_provider_mapping={"Token": "Token", "Authorization": "Authorization"},
    client_id="kerneltest-client",
    client_secret="notsecret",
    useragent="kerneltest-client",
)

req = requests.post(
    "https://kerneltest.fedoraproject.org/upload/anonymous",
    auth=OpenIDCClientAuther(
        client,
        [
            "openid",
            "email",
            "profile",
            "https://id.fedoraproject.org/scope/groups",
            "https://id.fedoraproject.org/scope/agreements",
            "https://id.fedoraproject.org/scope/fas-attributes",
        ]
    ),
    files={ 'test_result': ('logfile', open(log, 'rb'), 'text/plain'),},
)

print(req.text)
